<?php
// $Id: template.php,v 1.12.2.1 2007/01/17 05:28:41 jjeff Exp $

/**
 * @file
 * File which contains theme overrides for the Zen theme.
 */

/*
 * ABOUT
 *
 *  The template.php file is one of the most useful files when creating or modifying Drupal themes.
 *  You can add new regions for block content, modify or override Drupal's theme functions,
 *  intercept or make additional variables available to your theme, and create custom PHP logic.
 *  For more information, please visit the Theme Developer's Guide on Drupal.org:
 *  http://drupal.org/node/509
 */


/*
 * MODIFYING OR CREATING REGIONS
 *
 * Regions are areas in your theme where you can place blocks.
 * The default regions used in themes  are "left sidebar", "right sidebar", "header", and "footer",  although you can create
 * as many regions as you want.  Once declared, they are made available to the page.tpl.php file as a variable.
 * For instance, use <?php print $header ?> for the placement of the "header" region in page.tpl.php.
 *
 * By going to  the administer > site building > blocks page you can choose which regions various blocks should be placed.
 * New regions you define here will automatically show up in the drop-down list by their human readable name.
 */


/*
 * Declare the available regions implemented by this engine.
 *
 * @return
 *    An array of regions.  The first array element will be used as the default region for themes.
 *    Each array element takes the format: variable_name => t('human readable name')
 */
function trails_zen_regions() {
  return array(
       'left' => t('left sidebar'),
       'right' => t('right sidebar'),
       'content_top' => t('content top'),
       'content_bottom' => t('content bottom'),
       'header' => t('header'),
       'footer' => t('footer'),
       'above_tabs' => t('above tabs'),
  );
}

/*
 * OVERRIDING THEME FUNCTIONS
 *
 *  The Drupal theme system uses special theme functions to generate HTML output automatically.
 *  Often we wish to customize this HTML output.  To do this, we have to override the theme function.
 *  You have to first find the theme function that generates the output, and then "catch" it and modify it here.
 *  The easiest way to do it is to copy the original function in its entirety and paste it here, changing
 *  the prefix from theme_ to zen_.  For example:
 *
 *   original:  theme_breadcrumb()
 *   theme override:   zen_breadcrumb()
 *
 *  See the following example. In this theme, we want to change all of the breadcrumb separator links from  >> to ::
 *
 */

 /**
  * Return a themed breadcrumb trail.
  *
  * @param $breadcrumb
  *   An array containing the breadcrumb links.
  * @return a string containing the breadcrumb output.
  */
 function trails_zen_breadcrumb($breadcrumb) {
   $total = count($breadcrumb) - 1;

   if (!empty($breadcrumb)) {
     $title = drupal_get_title();

     // If the title is empty, let's grab it from the menu item so we don't render a blank breadcrumb
     if (empty($title)) {
       $menu_item = menu_get_item(menu_get_active_item());
       $title = l(t($menu_item['title']), $menu_item['path']);
     }
     $breadcrumb[] = $title;

     foreach ($breadcrumb as $crumb) {
       if ($count++ == $total) {
         $crumbs[] = '<span class="currentcrumb">'. $crumb .'</span>';
       }
       else {
         $crumbs[] = '<span class="crumb">'. $crumb .'</span>';
       }
     }
     return '<div class="breadcrumb">'. implode(' &rsaquo; ', $crumbs) .'</div>';
   }
 }


/*
 * CREATE OR MODIFY VARIABLES FOR YOUR THEME
 *
 *  The most powerful function available to themers is the _phptemplate_variables() function. It allows you
 *  to pass newly created variables to different template (tpl.php) files in your theme. Or even unset ones you don't want
 *  to use.
 *
 *  It works by switching on the hook, or name of the theme function, such as:
 *    - page
 *    - node
 *    - comment
 *    - block
 *
 * By switching on this hook you can send different variables to page.tpl.php file, node.tpl.php
 * (and any other derivative node template file, like node-forum.tpl.php), comment.tpl.php, and block.tpl.php
 *
 */


/**
 * Intercept template variables
 *
 * @param $hook
 *   The name of the theme function being executed
 * @param $vars
 *   A sequential array of variables passed to the theme function.
 */

function _phptemplate_variables($hook, $vars = array()) {
  switch ($hook) {
    // Send a new variable, $logged_in, to page.tpl.php to tell us if the current user is logged in or out.
    case 'page':
      // get the currently logged in user
      global $user;

			// remove sidebar on view/hike page
			if ($_GET['q'] == 'view/hike' || $vars['node']->type == 'hike' || $_GET['q'] == 'view/parks' || $vars['node']->type == 'park') {
			  $vars['sidebar_right'] = '';
			}
      // An anonymous user has a user id of zero.
      if ($user->uid > 0) {
        // The user is logged in.
        $vars['logged_in'] = TRUE;
      }
      else {
        // The user has logged out.
        $vars['logged_in'] = FALSE;
      }
      //implement head_title variable
      if (module_exists('page_title')) {
        $vars['head_title'] = page_title_page_get_title();
      }


      $body_classes = array();
      // classes for body element
      // allows advanced theming based on context (home page, node of certain type, etc.)
      $body_classes[] = ($vars['is_front']) ? 'front' : 'not-front';
      $body_classes[] = ($vars['logged_in']) ? 'logged-in' : 'not-logged-in';
      if ($vars['node']->type) {
        $body_classes[] = 'ntype-'. zen_id_safe($vars['node']->type);
      }
      switch (TRUE) {
      	case $vars['sidebar_left'] && $vars['sidebar_right'] :
      		$body_classes[] = 'both-sidebars';
      		break;
      	case $vars['sidebar_left'] :
      		$body_classes[] = 'sidebar-left';
      		break;
      	case $vars['sidebar_right'] :
      		$body_classes[] = 'sidebar-right';
      		break;
      }
      if (arg(0) == 'cart' && arg(1) == NULL) {
        $body_classes[] = 'cart';
      }
      if (arg(0) == 'cart' && arg(1) == 'checkout') {
        $body_classes[] = 'cart-checkout';
      }

      if ($user->uid == 0 && in_array($_GET['q'], array('user/register', 'user', 'user/password', 'user/login'))) {
        $body_classes[] = 'page-user';
      }

      if ($_GET['q'] == 'user/register') {
        $body_classes[] = 'page-register';
      }

      // implode with spaces
      $vars['body_classes'] = implode(' ', $body_classes);

      break;

    case 'node':
      // get the currently logged in user
      global $user;

      // set a new $is_admin variable
      // this is determined by looking at the currently logged in user and seeing if they are in the role 'admin'
      $vars['is_admin'] = in_array('admin', $user->roles);

      $node_classes = array('node');
      if ($vars['sticky']) {
      	$node_classes[] = 'sticky';
      }
      if (!$vars['node']->status) {
      	$node_classes[] = 'node-unpublished';
      }
      $node_classes[] = 'ntype-'. zen_id_safe($vars['node']->type);
      // implode with spaces
      $vars['node_classes'] = implode(' ', $node_classes);

      break;

    case 'comment':
      // we load the node object that the current comment is attached to
      $node = node_load($vars['comment']->nid);
      // if the author of this comment is equal to the author of the node, we set a variable
      // then in our theme we can theme this comment differently to stand out
      $vars['author_comment'] = $vars['comment']->uid == $node->uid ? TRUE : FALSE;
      break;
  }

  return $vars;
}

/**
* Converts a string to a suitable html ID attribute.
* - Preceeds initial numeric with 'n' character.
* - Replaces space and underscore with dash.
* - Converts entire string to lowercase.
* - Works for classes too!
*
* @param string $string
*  the string
* @return
*  the converted string
*/
function zen_id_safe($string) {
  if (is_numeric($string{0})) {
    // if the first character is numeric, add 'n' in front
    $string = 'n'. $string;
  }
  return strtolower(preg_replace('/[^a-zA-Z0-9-]+/', '-', $string));
}

/**
 * Theme checkout form
 *
 * @param unknown_type $form
 * @return unknown
 */
function trails_zen_uc_cart_checkout_form($form) {
  global $user;
  drupal_add_css(drupal_get_path('module', 'uc_cart') .'/uc_cart.css');

  $output = '<div>'. check_markup(variable_get('uc_checkout_instructions', ''), variable_get('uc_checkout_instructions_format', 3), FALSE) .'</div>';

  // style custom cart area
  foreach (element_children($form['panes']['cart']) as $cart_pane_id) {
    $output .= drupal_render($form['panes']['cart'][$cart_pane_id]);
  }
  unset($form['panes']['cart']);

  // style custom customer area
  if ($user->uid == 0) {
    // remove elements from own fieldset
    foreach(element_children($form['panes']['customer']['new_account']) as $new_account_field) {
      $form['panes']['customer'][$new_account_field] = $form['panes']['customer']['new_account'][$new_account_field];
    }
    unset($form['panes']['customer']['new_account']);

    // put elements to table
    $rows = array();
    foreach(element_children($form['panes']['customer']) as $field) {
      $title = $form['panes']['customer'][$field]['#title'];
      if ($form['panes']['customer'][$field]['#required']) {
        $title = '<span class="form-required">*</span> '. $title;
      }
      unset($form['panes']['customer'][$field]['#title']);
      $rows[] = array(
        array('data' => $title, 'class' => 'label'),
        array('data' => drupal_render($form['panes']['customer'][$field]), 'class' => 'field')
      );
    }
    $table = theme('table', array(), $rows, array('class' => 'checkout-pane-table'));
    $content = '<div class="content"><p>'. $form['panes']['customer']['#description'] . '</p>'. $table .'</div>';

    $wrapper = '<div id="customer-pane" class="pane-light checkout-pane"><h2>'. t('Customer Information') .'</h2>'. $content .'</div>';

    $output .= $wrapper;

    $join_now = l('> '. t('Join Now'), 'membership');
    $content = <<<TEXT
    <div class="content">
    <p class="subtitle">SAVE 25%</p>
    <p>If you are not already a member, or are not in the process of joining, join now and get a 25% discount on the merchandise in your cart. Add a membership to your cart before completing the checkout process!</p>
    <p>{$join_now}</p>
    </div>
TEXT;

    $wrapper = '<div id="join-now-pane" class="pane-dark"><h2>'. t('Member benefits') .'</h2>'. $content .'</div>';

    $output .= $wrapper .'<div class="stop"></div>';
    unset($form['panes']['customer']);
  }
  // else we have logged user
  else {
    $output .= drupal_render($form['panes']['customer']['primary_email']);
    $output .= drupal_render($form['panes']['customer']['email_text']);
    unset($form['panes']['customer']);
  }

  // deal with customer delivery information
  if (isset($form['panes']['delivery'])) {
    $rows = array();
    $rows[] = array(
          array('data' => drupal_render($form['panes']['delivery']['delivery_post_info']), 'colspan' => 2)
        );
    foreach(element_children($form['panes']['delivery']) as $field) {
      $skip_fields = array('delivery_zone', 'delivery_postal_code', 'delivery_post_info');
      if (in_array($field, $skip_fields)) {
        continue;
      }

      $title = $form['panes']['delivery'][$field]['#title'];
      if ($form['panes']['delivery'][$field]['#required']) {
        $title = '<span class="form-required">*</span> '. $title;
      }
      unset($form['panes']['delivery'][$field]['#title']);
      if ($field == 'delivery_city') {
        $form['panes']['delivery']['delivery_postal_code']['#title'] = t('Zip');
        $form['panes']['delivery']['delivery_city']['#size'] = 20;
        $data = drupal_render($form['panes']['delivery'][$field]) .
                drupal_render($form['panes']['delivery']['delivery_zone']) .
                drupal_render($form['panes']['delivery']['delivery_postal_code']);
        $rows[] = array(
          array('data' => $title, 'class' => 'label'),
          array('data' => $data, 'class' => 'field')
        );
      }
      else {
        $rows[] = array(
          array('data' => $title, 'class' => 'label'),
          array('data' => drupal_render($form['panes']['delivery'][$field]), 'class' => 'field')
        );
      }
    }
    $table = theme('table', array(), $rows, array('class' => 'checkout-pane-table'));
    $wrapper = '<div id="delivery-pane" class="pane-light checkout-pane"><h2>'. t('Shipping Information') .'</h2><div class="address-pane-table">'. $table .'</div></div>';
    $output .= $wrapper;

    foreach (element_children($form['panes']['delivery']) as $element) {
      $output .= drupal_render($form['panes']['delivery'][$element]);
    }
    unset($form['panes']['delivery']);
  }

  // deal with customer delivery information
  if (isset($form['panes']['billing'])) {
    $button = drupal_render($form['panes']['billing']['copy_address']);
    $rows = array();
    foreach(element_children($form['panes']['billing']) as $field) {
      $skip_fields = array('billing_zone', 'billing_postal_code', 'copy_address');
      if (in_array($field, $skip_fields)) {
        continue;
      }

      $title = $form['panes']['billing'][$field]['#title'];
      if ($form['panes']['billing'][$field]['#required']) {
        $title = '<span class="form-required">*</span> '. $title;
      }
      unset($form['panes']['billing'][$field]['#title']);
      if ($field == 'billing_city') {
        $form['panes']['billing']['billing_postal_code']['#title'] = t('Zip');
        $form['panes']['billing']['billing_city']['#size'] = 20;
        $data = drupal_render($form['panes']['billing'][$field]) .
                drupal_render($form['panes']['billing']['billing_zone']) .
                drupal_render($form['panes']['billing']['billing_postal_code']);
        $rows[] = array(
          array('data' => $title, 'class' => 'label'),
          array('data' => $data, 'class' => 'field')
        );
      }
      else {
        $rows[] = array(
          array('data' => $title, 'class' => 'label'),
          array('data' => drupal_render($form['panes']['billing'][$field]), 'class' => 'field')
        );
      }
    }
    $table = theme('table', array(), $rows, array('class' => 'checkout-pane-table'));
    $wrapper = '<div id="billing-pane" class="pane-light checkout-pane"><h2>'. t('Billing Information') .'</h2>'. $button .'<div class="address-pane-table">'. $table .'</div></div>';
    $output .= $wrapper;
     foreach (element_children($form['panes']['billing']) as $element) {
      $output .= drupal_render($form['panes']['billing'][$element]);
    }
    unset($form['panes']['billing']);
  }

  // alter quotes form
  if (isset($form['panes']['quotes'])) {
    unset($form['panes']['quotes']['quote']);
    $rows = array();
    $rows[] = array(
      array('data' => $form['panes']['quotes']['#description'], 'class' => 'description'),
//      array('data' => theme('image', drupal_get_path('theme', 'trails_zen') .'/images/checkout-arrow.png')),
//      array('data' => drupal_render($form['panes']['quotes']['quote_button']))
    );

    $table = theme('table', array(), $rows, array('id' => 'calculate-shipping-button'));
    unset($form['panes']['quotes']['#description']);
    $form['panes']['quotes']['rendered'] = array(
      '#type' => 'markup',
      '#value' => $table,
      '#weight' => -10
    );

    $output .= drupal_render($form['panes']['quotes']);
  }

  if ($form['panes']['payment']) {
    // build quote and sum field
    unset($form['panes']['payment']['shown_total']);
    $total = '<div id="line-items-div"><em>Javascript must be enabled to view the order total preview.</em></div>';
    $output .= '<div id="summary-pane"><div id="quote">&nbsp;</div><div id="summary-total">'. $total .'</div><div class="stop"></div></div>';
    $output .= '<div class="stop"></div>';
    unset($form['panes']['payment']['#description']);

    $rows = array();
    $title = $form['panes']['payment']['payment_method']['#title'];
    if ($form['panes']['payment']['payment_method']['#required']) {
      $title = '<span class="form-required">*</span> '. $title;
    }
    unset($form['panes']['payment']['payment_method']['#title']);

    $rows[] = array(
      array('data' => $title, 'class' => 'label'),
      array('data' => drupal_render($form['panes']['payment']['payment_method']), 'class' => 'field')
    );

    $form['panes']['payment']['render'] = array(
      '#type' => 'markup',
      '#value' => theme('table', array(), $rows, array('class' => 'checkout-payment-table'))
    );
  }

  // alter comments form
  if (isset($form['panes']['comments'])) {
    $form['panes']['comments']['#title'] = t('Other Instructions');
    unset($form['panes']['comments']['#description'], $form['panes']['comments']['comments']['#title']);
    $form['panes']['comments']['comments']['#rows'] = 5;
    $form['panes']['comments']['comments']['#cols'] = 78;
    $rows = array();
    $rows[] = array(
      array('data' => '', 'class' => 'label'),
      array('data' => drupal_render($form['panes']['comments']['comments']), 'class' => 'field')
    );
    $form['panes']['comments']['render'] = array(
      '#type' => 'markup',
      '#value' => theme('table', array(), $rows, array('id' => 'comments-input'))
    );
  }

  if (arg(1) == 'checkout2') {
    foreach (element_children($form['panes']) as $pane_id) {
      $output .= drupal_render($form['panes'][$pane_id]);
    }
  }
  else {
    foreach (element_children($form['panes']) as $pane_id) {
      if (function_exists(($func = _checkout_pane_data($pane_id, 'callback')))) {
        $result = $func('theme', $form['panes'][$pane_id], NULL);
        if (!empty($result)) {
          $output .= $result;
          $form['panes'][$pane_id] = array();
        }
        else {
          $output .= drupal_render($form['panes'][$pane_id]);
        }
      }
      else {
        $output .= drupal_render($form['panes'][$pane_id]);
      }
    }
  }

  $output .= '<div id="checkout-form-bottom">'. drupal_render($form) .'</div>';

  return $output;
}

/**
 * Theme user reigstration page
 */
function trails_zen_user_register(&$form) {
//  print '<pre>'. print_r($form['simplenews'], true) .'</pre>';
  drupal_set_title('Create User Account Start');

  $form['submit']['#prefix'] = '<div class="form-submit-button">';
  $form['submit']['#suffix'] = '</div>';

  // basic account
  $form['_title_account'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">'. check_plain($form['account']['#title']) .'</h2>', '#weight' => $form['account']['#weight'] - 0.1);
  $form['account']['mail']['#description'] = '&nbsp;';
  unset($form['account']['#title']);

  // subscription
  $form['simplenews']['#weight'] = $form['account']['#weight'] + 0.001;
  $form['simplenews']['simplenews-39']['#prefix'] = '<div class="form-item"><label>'. t('Subscribe to e-Walker') .':</label>';
  $form['simplenews']['simplenews-39']['#suffix'] .= '</div>';
  $form['simplenews']['simplenews-39']['#title'] = t('Yes');
  $form['simplenews']['#attributes']['class'] = 'simplenews';

  // membership #
  $form['Membership']['#weight'] = $form['simplenews']['#weight'] + 0.001;
  $form['Membership']['#title'] = t('Trail Conference Membership Status');
  $form['Membership']['#attributes']['class'] = 'membership';
  $form['Membership']['profile_member']['#title'] = t('If Yes, Membership #');
  $form['Membership']['profile_member']['#description'] = '&nbsp;';
  $form['Membership']['profile_member']['#field_suffix'] = '&nbsp;&nbsp;(optional; can be found on your membership card)';
  $form['Membership']['profile_member']['#size'] = 10;
  unset($form['Membership']['private_profile_member'], $form['Membership']['profile_expire'], $form['Membership']['private_profile_expire']);
  $form['_title_membership'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">'. check_plain($form['Membership']['#title']) .'</h2>', '#weight' => $form['Membership']['#weight'] - 0.0001);

  // address
  $form[0]['#weight'] = $form['Membership']['#weight'] + 0.001;
  $form[0]['#description'] = t('In order to verify your membership status, we need to know your real name and zipcode');
  $form[0]['#attributes']['class'] = 'address';
  foreach (element_children($form[0]) as $field) {
    $form[0][$field]['#description'] = '&nbsp;';
  }
  $form['_title_address'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">'. check_plain($form[0]['#title']) .'</h2>', '#weight' => $form[0]['#weight'] - 0.0001);
  unset($form[0]['#title']);

  // captcha (mollom)
  $form['captcha-solution']['#weight'] = $form[0]['#weight'] + 0.001;
  $form['captcha-solution']['#title'] = t('Verification');
  $form['captcha-solution']['#field_prefix'] = preg_replace('~<div id="captcha">([^(]+)(\([^)]+\)).*</div>~', '<div id="captcha">$1</div>', $form['captcha-solution']['#field_prefix']);
  $form['captcha-solution']['#field_prefix'] .= '<div class="captcha-input"><div>'. $form['captcha-solution']['#description'] .'</div></div>';
  $form['captcha-solution']['#field_suffix'] .= '<div class="clear">(<a id="audio-captcha" href="#">play audio CAPTCHA</a>)</div>';
  unset($form['captcha-solution']['#description']);
  $form['_title_captcha'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">'. check_plain($form['captcha-solution']['#title']) .'</h2>', '#weight' => $form['captcha-solution']['#weight'] - 0.0001);

  // and now remove everything what isn't on mockup (temporary)
  $enabled_fields = array('session-id', 'form_id', '_title_account', 'simplenews', 'account', 'Membership', '_title_membership', "0", '_title_address', 'captcha-solution', '_title_captcha', 'submit');
  foreach (element_children($form) as $field) {
    if (!in_array("$field", $enabled_fields)) {
      unset($form[$field]);
    }
  }
  return drupal_render($form);
}

/**
 * Changes for registration page
 *
 * @param unknown_type $form
 * @return unknown
 */
function trails_zen_user_login(&$form) {
  drupal_set_title('Log in');

  $form['_title_login'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">&nbsp;</h2>', '#weight' => -2);
  $form['submit']['#prefix'] = '<div class="form-submit-button">';
  $form['submit']['#suffix'] = '</div>';
  unset($form['openid_identifier'], $form['openid_link'], $form['user_link'], $form['openid.return_to']);
  return drupal_render($form);
}

function trails_zen_user_pass(&$form) {
  drupal_set_title('Request New Password');

  $form['submit']['#prefix'] = '<div class="form-submit-button">';
  $form['submit']['#suffix'] = '</div>';

  $form['_title_name'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">&nbsp;</h2>', '#weight' => -2);
  $form['name']['#description'] = '&nbsp;';

  // captcha (mollom)
  $form['captcha-solution']['#title'] = t('Verification');
  $form['captcha-solution']['#field_prefix'] = preg_replace('~<div id="captcha">([^(]+)(\([^)]+\)).*</div>~', '<div id="captcha">$1</div>', $form['captcha-solution']['#field_prefix']);
  $form['captcha-solution']['#field_prefix'] .= '<div class="captcha-input"><div>'. $form['captcha-solution']['#description'] .'</div></div>';
  $form['captcha-solution']['#field_suffix'] .= '<div class="clear">(<a id="audio-captcha" href="#">play audio CAPTCHA</a>)</div>';
  unset($form['captcha-solution']['#description']);
  $form['_title_captcha'] = array('#type' => 'markup', '#value' => '<h2 class="group-title">'. check_plain($form['captcha-solution']['#title']) .'</h2>', '#weight' => $form['captcha-solution']['#weight'] - 0.0001);
  return drupal_render($form);
}

function trails_zen_form_render_table($form, $fields) {
  $output = '';
  $rows = array();
  $header = array();
  foreach ($fields as $field) {
    $form[$field]['#required'];
    $form[$field]['#title'];
  }
}

function trails_zen_uc_product_price($price, $class) {
  $output = '<div class="'. $class .'">';
  switch ($class) {
    case 'list_price':
      $output .= uc_currency_format($price);
    break;
    case 'cost':
      $output .= t('Cost: !price', array('!price' => uc_currency_format($price)));
    break;
    case 'sell_price':
    default:
      $output .= t('Price: !price', array('!price' => uc_currency_format($price)));
    break;
  }
  $output .= '</div>';
  return $output;
}

/**
 * Custom 2-color zebra
 */
function trails_zen_views_view_table_parks_table($view, $nodes, $type) {
  $fields = _views_get_fields();

  $class = 'style-';
  $i = 0;
  foreach ($nodes as $node) {
    $row = array();
    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        $cell['data'] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
        $cell['class'] = "view-field ". views_css_safe('view-field-'. $field['queryname']);
        $row[] = $cell;
      }
    }
    $style_class = $class . (($i++ % 2) + 1);
    $row = array('data' => $row, 'class' => $style_class);
    $rows[] = $row;
  }
  return theme('table', $view->table_header, $rows);
}

/**
 * Custom 2-color zebra
 */
function trails_zen_views_view_table_hike_table($view, $nodes, $type) {
  $fields = _views_get_fields();

  $class = 'style-';
  $i = 0;
  foreach ($nodes as $node) {
    $row = array();
    foreach ($view->field as $field) {
      if ($fields[$field['id']]['visible'] !== FALSE) {
        $cell['data'] = views_theme_field('views_handle_field', $field['queryname'], $fields, $field, $node, $view);
        $cell['class'] = "view-field ". views_css_safe('view-field-'. $field['queryname']);
        $row[] = $cell;
      }
    }
    $style_class = $class . (($i++ % 2) + 1);
    $row = array('data' => $row, 'class' => $style_class);
    $rows[] = $row;
  }
  return theme('table', $view->table_header, $rows);
}


/**
 * Add Advertising block on view Parks table
 */
function trails_zen_views_view_parks_table($view, $type, $nodes, $level = NULL, $args = NULL) {
  $num_nodes = count($nodes);

  if ($type == 'page') {
    drupal_set_title(filter_xss_admin(views_get_title($view, 'page')));
    views_set_breadcrumb($view);
  }

  $output .= '<div class="view-block-wrapper">';
  $output .= '<div class="view-block-left">';
  if ($num_nodes) {
    $output .= views_get_textarea($view, $type, 'header');
  }

  if ($type != 'block' && $view->exposed_filter) {
    $output .= views_theme('views_display_filters', $view);
  }
  $output .= '</div><div class="view-block-right">';

  // TODO: replace advertisment block here
  $output .= '<div> <a target=_blank href="http://www.ramseyoutdoor.com"><img src="/files/images/nynjtc_ramsey.jpg" alt="Ramsey Ad" title="Ramsey Ad"  class="image image-preview " width="300" height="250" /></a></div>';

  $output .= '</div><div class="stop"></div></div>';

  $output .= '<div class="table-note"><strong>Note:</strong> To sort a Column, click on the heading for each column.</div>';

  $plugins = _views_get_style_plugins();
  $view_type = ($type == 'block') ? $view->block_type : $view->page_type;
  if ($num_nodes || $plugins[$view_type]['even_empty']) {
    if ($level !== NULL) {
      $output .= "<div class='view-summary ". views_css_safe('view-summary-'. $view->name) ."'>". views_theme($plugins[$view_type]['summary_theme'], $view, $type, $level, $nodes, $args) . '</div>';
    }
    else {
      $output .= "<div class='view-content ". views_css_safe('view-content-'. $view->name) ."'>". views_theme($plugins[$view_type]['theme'], $view, $nodes, $type) . '</div>';
    }
    $output .= views_get_textarea($view, $type, 'footer');

    if ($type == 'block' && $view->block_more && $num_nodes >= $view->nodes_per_block) {
      $output .= theme('views_more', $view->real_url);
    }
  }
  else {
    $output .= views_get_textarea($view, $type, 'empty');
  }

  if ($view->use_pager) {
    $output .= theme('pager', '', $view->pager_limit, $view->use_pager - 1);
  }

  if ($output) {
    $output = "<div class='view ". views_css_safe('view-'. $view->name) ."'>$output</div>\n";
  }
  return $output;
}

/**
 * Add Advertising block on view
 */
function trails_zen_views_view_Hike_table($view, $type, $nodes, $level = NULL, $args = NULL) {
  $num_nodes = count($nodes);

  if ($type == 'page') {
    drupal_set_title(filter_xss_admin(views_get_title($view, 'page')));
    views_set_breadcrumb($view);
  }

  $output .= '<div class="view-block-wrapper">';
  $output .= '<div class="view-block-left">';
  if ($num_nodes) {
    $output .= views_get_textarea($view, $type, 'header');
  }

  if ($type != 'block' && $view->exposed_filter) {
    $output .= views_theme('views_display_filters', $view);
  }
  $output .= '</div><div class="view-block-right">';

  // TODO: replace advertisment block here
  /* $output .= '<div> <object classid="clsid:d27cdb6e-ae6d-11cf-96b8-444553540000" codebase="http://download.macromedia.com/pub/shockwave/cabs/flash/swflash.cab#version=9,0,0,0" width="300" height="250" id="Campmor-300x250" align="middle">
	<param name="allowScriptAccess" value="sameDomain" />
	<param name="allowFullScreen" value="false" />
	<param name="movie" value="/files/Campmor-300x250.swf" /><param name="quality" value="high" /><param name="bgcolor" value="#ffffff" />	<embed src="/files/Campmor-300x250.swf" quality="high" bgcolor="#ffffff" width="300" height="250" name="Campmor-300x250" align="middle" allowScriptAccess="sameDomain" allowFullScreen="false" type="application/x-shockwave-flash" pluginspage="http://www.macromedia.com/go/getflashplayer" />
	</object></div>';

  $output .= '</div><div class="stop"></div></div>';
*/
 $output .= '<div> <a target=_blank href="http://www.campmor.com/outdoor/gear/Home_"><img src="/sites/all/themes/trails_zen/images/new_campmor.gif" alt="Campmor Ad" title="Campmor Ad"  class="image image-preview " width="300" height="250" /></a></div>';

  $output .= '</div><div class="stop"></div></div>';

  $output .= '<div class="table-note"><strong>Note:</strong> To sort a Column, click on the heading for each column.</div>';

  $plugins = _views_get_style_plugins();
  $view_type = ($type == 'block') ? $view->block_type : $view->page_type;
  if ($num_nodes || $plugins[$view_type]['even_empty']) {
    if ($level !== NULL) {
      $output .= "<div class='view-summary ". views_css_safe('view-summary-'. $view->name) ."'>". views_theme($plugins[$view_type]['summary_theme'], $view, $type, $level, $nodes, $args) . '</div>';
    }
    else {
      $output .= "<div class='view-content ". views_css_safe('view-content-'. $view->name) ."'>". views_theme($plugins[$view_type]['theme'], $view, $nodes, $type) . '</div>';
    }
    $output .= views_get_textarea($view, $type, 'footer');

    if ($type == 'block' && $view->block_more && $num_nodes >= $view->nodes_per_block) {
      $output .= theme('views_more', $view->real_url);
    }
  }
  else {
    $output .= views_get_textarea($view, $type, 'empty');
  }

  if ($view->use_pager) {
    $output .= theme('pager', '', $view->pager_limit, $view->use_pager - 1);
  }

  if ($output) {
    $output = "<div class='view ". views_css_safe('view-'. $view->name) ."'>$output</div>\n";
  }
  return $output;
}
